@@ -1,6 +1,6 @@
-/* $Id: xfce-miscutils.h 17217 2005-08-31 10:19:12Z benny $ */
+/* $Id$ */
 /*-
- * Copyright (c) 2003-2005 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -23,39 +23,25 @@
 #error "Only <libxfce4util/libxfce4util.h> can be included directly, this file may disappear or change contents"
 #endif
 
-#ifndef __LIBXFCE4UTIL_MISCUTILS_H__
-#define __LIBXFCE4UTIL_MISCUTILS_H__
+#ifndef __XFCE_MISCUTILS_H__
+#define __XFCE_MISCUTILS_H__
 
 #include <glib.h>
 
 #include <libxfce4util/debug.h>
 
-/* This looks a bit "hacky", but its ok */
-#define _BUILTIN_LICENSE_TEXT(name) \
-({ \
-  extern const char xfce_builtin_license_##name[]; \
-  xfce_builtin_license_##name; \
-})
-
-#define XFCE_LICENSE_BSD  _BUILTIN_LICENSE_TEXT(BSD)
-
-#define XFCE_LICENSE_GPL  _BUILTIN_LICENSE_TEXT(GPL)
-
-#define XFCE_LICENSE_LGPL _BUILTIN_LICENSE_TEXT(LGPL)
-
-
 const gchar* xfce_version_string (void) G_GNUC_PURE;
 
 const gchar* xfce_get_homedir    (void) G_GNUC_PURE;
 
-gchar* xfce_get_homefile_r       (gchar *buffer,
+gchar*       xfce_get_homefile_r (gchar *buffer,
                                   size_t length, 
                                   const gchar *format,
                                   ...);
 
 const gchar* xfce_get_userdir    (void) G_GNUC_PURE;
 
-gchar* xfce_get_userfile_r       (gchar *buffer,
+gchar*       xfce_get_userfile_r (gchar *buffer,
                                   size_t length, 
                                   const gchar *format,
                                   ...);
@@ -92,20 +78,20 @@ xfce_get_userfile (const gchar *first_element, ...)
 
 #endif
 
-gchar*  xfce_strjoin     (const gchar *separator,
-                          gchar **strings,
-                          gint count);
+gchar*  xfce_strjoin          (const gchar *separator,
+                               gchar      **strings,
+                               gint         count) G_GNUC_MALLOC;
 
-gchar*  xfce_gethostname (void) G_GNUC_PURE;
+gchar*  xfce_gethostname      (void) G_GNUC_MALLOC;
 
-gint    xfce_putenv      (const gchar *string);
+gint    xfce_putenv           (const gchar *string);
 
-gint    xfce_setenv      (const gchar *name,
-                          const gchar *value,
-                          gboolean overwrite);
-void    xfce_unsetenv    (const gchar *name);
+gint    xfce_setenv           (const gchar *name,
+                               const gchar *value,
+                               gboolean     overwrite);
+void    xfce_unsetenv         (const gchar *name);
 
 gchar*  xfce_expand_variables (const gchar *command,
-                               gchar      **envp);
+                               gchar      **envp) G_GNUC_MALLOC;
 
-#endif	/* __LIBXFCE4UTIL_MISCUTILS_H__ */
+#endif	/* __XFCE_MISCUTILS_H__ */
